@@ -1,9 +1,6 @@
 package Constant::FromGlobal;
-{
-  $Constant::FromGlobal::VERSION = '0.05';
-}
 # ABSTRACT: declare constant(s) with value from global or environment variable
-
+$Constant::FromGlobal::VERSION = '0.06';
 use strict;
 use warnings;
 use 5.8.0;
@@ -33,21 +30,21 @@ sub process_constants {
 
     my $options = Data::OptList::mkopt(delete $args{constants}, "constant", 1, [qw(HASH ARRAY)]);
 
-    my %constants;
+    my $constants = {};
 
     my $caller = $args{package};
 
     foreach my $constant ( @$options ) {
         my ( $name, $opt ) = @$constant;
 
-        $constants{$name} = $class->get_value(
+        $constants->{$name} = $class->get_value(
             %args,
             name => $name,
             %$opt,
         );
     }
 
-    return %constants;
+    return $constants;
 }
 
 sub get_value {
